.. Embasi documentation master file, created by
   sphinx-quickstart on Wed Aug 21 16:58:58 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

ASI Embedding Documentation
===========================

EmbASI is a Python wrapper for running QM-in-QM embedding simulations. The software package provides communincation protocols for matrix quantities between instances of different QM code system calls through the `ASI (Atomic Simulation Interface) API <https://gitlab.com/pvst/asi>`_. Inputs such as atomic structures and QM code keywords are comtrolled through integration with the `Atomic Simulation Environment (ASE) <https://wiki.fysik.dtu.dk/ase/>`_.

The software is currently under active development and is subject to major changes.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   installation
   explainer
   codeintegration
   modules

Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
